@@ -19,8 +19,11 @@ _rlock = threading.RLock()
 def do_execute(target, rule, msgfield, prefix=None):
     def sprint(*args, **kwargs):
         """print for multithread build"""
-        with _rlock:
-            print(*args, **kwargs)
+        try:
+            with _rlock:
+                print(*args, **kwargs)
+        except Exception as e:
+            print("Licant: Print error:", e)
 
     rule = rule.format(**target.__dict__)
 
@@ -386,3 +389,21 @@ class MakeCore(Core):
         target.dirkeep = licant.util.do_nothing
         target.update_status = UpdateStatus.Keeped
         return target
+
+    def ftarget(self, tgt, build=None, deps=[], exec=None, message="FTARGET {tgt}"):
+        """Make the file target."""
+        if exec is not None:
+            build = licant.Executor(exec)
+
+        if build is None:
+            raise Exception("build action is None")
+
+        tgt = os.path.expanduser(str(tgt))
+        dirdeps = self.dirkeep(tgt)
+        return self.add(FileTarget(
+            tgt=tgt,
+            build=build,
+            deps=deps + dirdeps,
+            use_dirkeep=False,
+            message=message
+        ))
